@@ -5,9 +5,7 @@ from django.conf import settings
 # In our code, if we want to use a DITTO_TWITTER_* setting we should import
 # from here, not django.conf.settings.
 
-DITTO_TWITTER_DIR_BASE = getattr(settings, 'DITTO_TWITTER_DIR_BASE', 'twitter')
+TWITTER_DIR_BASE = getattr(settings, 'DITTO_TWITTER_DIR_BASE', 'twitter')
 
-DITTO_TWITTER_USE_LOCAL_MEDIA = getattr(settings,
+TWITTER_USE_LOCAL_MEDIA = getattr(settings,
                                     'DITTO_TWITTER_USE_LOCAL_MEDIA', False)
-
-
